acdh\_abbr\_client package
==========================

Submodules
----------

acdh\_abbr\_client.acdh\_abbr\_client module
--------------------------------------------

.. automodule:: acdh_abbr_client.acdh_abbr_client
    :members:
    :undoc-members:
    :show-inheritance:

acdh\_abbr\_client.cli module
-----------------------------

.. automodule:: acdh_abbr_client.cli
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: acdh_abbr_client
    :members:
    :undoc-members:
    :show-inheritance:
